@@ -180,9 +180,7 @@ static gboolean prop_get_string_utf8(Window win, Atom prop, gchar** ret) {
 
 int main(int argc, char** argv) {
   QApplication app(argc, argv);
-#ifndef USE_QT4
   app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
 
   // load translations
   QTranslator qtTranslator, translator;
@@ -196,8 +194,6 @@ int main(int argc, char** argv) {
   app.installTranslator(&translator);
 
   // load configurations
-  gchar* p;
-  gboolean exit_with_error = FALSE;
 
   parse_args(argc, argv);
 
@@ -226,7 +222,6 @@ int main(int argc, char** argv) {
                                 "openbox_config"))) {
     QMessageBox::critical(NULL, QObject::tr("Error"),
                           QObject::tr("Failed to load an rc.xml. You have probably failed to install Openbox properly."));
-    exit_with_error = TRUE;
   }
   else {
     doc = obt_xml_doc(parse_i);
@@ -241,7 +236,6 @@ int main(int argc, char** argv) {
       QString message = QObject::tr("Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.\n\nMessage: %1")
         .arg(QString::fromUtf8(e->message));
       QMessageBox::critical(NULL, QObject::tr("Error"), message);
-      exit_with_error = TRUE;
     }
   }
 
