@@ -17,237 +17,237 @@
 <context>
     <name>MainDialog</name>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1027"/>
+        <location filename="../obconf.ui" line="63"/>
         <source>Mouse</source>
         <translation>Ratón</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1012"/>
+        <location filename="../obconf.ui" line="14"/>
         <source>Window Manager Preferences</source>
         <translation>Preferencias del gestor de ventanas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1017"/>
+        <location filename="../obconf.ui" line="38"/>
         <source>Theme</source>
         <translation>Tema</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1019"/>
+        <location filename="../obconf.ui" line="43"/>
         <source>Appearance</source>
         <translation>Apariencia</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1021"/>
+        <location filename="../obconf.ui" line="48"/>
         <source>Font</source>
         <translation>Tipo de letra</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1023"/>
-        <location filename="../../build/src/ui_obconf.h" line="1038"/>
+        <location filename="../obconf.ui" line="53"/>
+        <location filename="../obconf.ui" line="114"/>
         <source>Windows</source>
         <translation>Ventanas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1025"/>
+        <location filename="../obconf.ui" line="58"/>
         <source>Move &amp; Resize</source>
         <translation>Mover y redimensionar</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1029"/>
+        <location filename="../obconf.ui" line="68"/>
         <source>Desktops</source>
         <translation>Escritorios</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1031"/>
+        <location filename="../obconf.ui" line="73"/>
         <source>Margins</source>
         <translation>Márgenes</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1033"/>
+        <location filename="../obconf.ui" line="78"/>
         <source>Dock</source>
-        <translation type="unfinished"></translation>
+        <translation>Muelle</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1041"/>
+        <location filename="../obconf.ui" line="137"/>
         <source>Window Titles</source>
         <translation>Títulos de las ventanas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1042"/>
+        <location filename="../obconf.ui" line="143"/>
         <source>Button order:</source>
         <translation>Orden de los botones:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1083"/>
+        <location filename="../obconf.ui" line="439"/>
         <source>Moving and Resizing Windows</source>
         <translation>Mover y redimensionar ventanas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1090"/>
+        <location filename="../obconf.ui" line="542"/>
         <source>Information Dialog</source>
         <translation>Diálogo de información</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1119"/>
+        <location filename="../obconf.ui" line="701"/>
         <source>Focusing Windows</source>
-        <translation>Enfocar ventanas</translation>
+        <translation>Activación de ventanas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1120"/>
+        <location filename="../obconf.ui" line="710"/>
         <source>Focus windows when the mouse pointer moves over them</source>
-        <translation>Enfocar las ventanas al pasar el ratón sobre ellas</translation>
+        <translation>Activar las ventanas al pasar el ratón sobre ellas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1125"/>
+        <location filename="../obconf.ui" line="768"/>
         <source>Titlebar</source>
         <translation>Barra de título</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1137"/>
+        <location filename="../obconf.ui" line="905"/>
         <source>Desktop Margins</source>
         <translation>Márgenes del escritorio</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1138"/>
+        <location filename="../obconf.ui" line="911"/>
         <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
         <translation>Los márgenes del escritorio son áreas reservadas en los bordes de la pantalla. Las ventanas nuevas no los ocuparán y las ventanas maximizadas no los cubrirán.</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1139"/>
+        <location filename="../obconf.ui" line="921"/>
         <source>Left:</source>
         <translation>Izquierdo:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1140"/>
-        <location filename="../../build/src/ui_obconf.h" line="1142"/>
-        <location filename="../../build/src/ui_obconf.h" line="1144"/>
-        <location filename="../../build/src/ui_obconf.h" line="1146"/>
+        <location filename="../obconf.ui" line="935"/>
+        <location filename="../obconf.ui" line="956"/>
+        <location filename="../obconf.ui" line="977"/>
+        <location filename="../obconf.ui" line="998"/>
         <source>px</source>
         <translation>px</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1141"/>
+        <location filename="../obconf.ui" line="942"/>
         <source>Top:</source>
         <translation>Superior:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1143"/>
+        <location filename="../obconf.ui" line="963"/>
         <source>Right:</source>
         <translation>Derecho:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1145"/>
+        <location filename="../obconf.ui" line="984"/>
         <source>Bottom:</source>
         <translation>Inferior:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1068"/>
+        <location filename="../obconf.ui" line="329"/>
         <source>All monitors</source>
         <translation>Todos los monitores</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1069"/>
+        <location filename="../obconf.ui" line="334"/>
         <source>The active monitor</source>
         <translation>El monitor activo</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1070"/>
+        <location filename="../obconf.ui" line="339"/>
         <source>The monitor with the mouse</source>
         <translation>El monitor que contiene el ratón</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1073"/>
+        <location filename="../obconf.ui" line="354"/>
         <source>Primary Monitor</source>
         <translation>Monitor primario</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1074"/>
+        <location filename="../obconf.ui" line="360"/>
         <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
         <translation>El monitor primario es donde Openbox ubicará los diálogos, como el usado para alternar las ventanas.</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1078"/>
+        <location filename="../obconf.ui" line="381"/>
         <source>Fixed Monitor</source>
         <translation>Monitor fijo</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1079"/>
+        <location filename="../obconf.ui" line="386"/>
         <source>Active Monitor</source>
         <translation>Monitor activo</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1080"/>
+        <location filename="../obconf.ui" line="391"/>
         <source>Monitor With Mouse Pointer</source>
         <translation>Monitor con el puntero del ratón</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1093"/>
-        <location filename="../../build/src/ui_obconf.h" line="1100"/>
+        <location filename="../obconf.ui" line="549"/>
+        <location filename="../obconf.ui" line="578"/>
         <source>Centered</source>
         <translation>Centrado</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1094"/>
+        <location filename="../obconf.ui" line="554"/>
         <source>From left edge</source>
         <translation>Desde el borde izquierdo</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1095"/>
+        <location filename="../obconf.ui" line="559"/>
         <source>From right edge</source>
         <translation>Desde el borde derecho</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1101"/>
+        <location filename="../obconf.ui" line="583"/>
         <source>From top edge</source>
         <translation>Desde el borde superior</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1102"/>
+        <location filename="../obconf.ui" line="588"/>
         <source>From bottom edge</source>
         <translation>Desde el borde inferior</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1109"/>
+        <location filename="../obconf.ui" line="641"/>
         <source>When resizing terminal windows</source>
         <translation>Al redimensionar ventanas de terminal</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1110"/>
+        <location filename="../obconf.ui" line="646"/>
         <source>Always</source>
         <translation>Siempre</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1111"/>
+        <location filename="../obconf.ui" line="651"/>
         <source>Never</source>
         <translation>Nunca</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1115"/>
+        <location filename="../obconf.ui" line="660"/>
         <source>Centered on the window</source>
         <translation>Centrado en la ventana</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1116"/>
+        <location filename="../obconf.ui" line="665"/>
         <source>Above the window</source>
-        <translation>Encima de la ventana</translation>
+        <translation>Sobre la ventana</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1117"/>
+        <location filename="../obconf.ui" line="670"/>
         <source>Fixed position on screen</source>
         <translation>Posición fija en la pantalla</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1129"/>
+        <location filename="../obconf.ui" line="785"/>
         <source>Maximizes the window</source>
         <translation>Maximiza la ventana</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1130"/>
+        <location filename="../obconf.ui" line="790"/>
         <source>Shades the window</source>
         <translation>Enrolla la ventana</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1043"/>
+        <location filename="../obconf.ui" line="153"/>
         <source>N: Window icon
 L: Window label (Title)
 I: Iconify (Minimize)
@@ -264,322 +264,322 @@ S: Enrollar
 D: Omnipresente (en todos los escritorios)</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1071"/>
+        <location filename="../obconf.ui" line="344"/>
         <source>Primary monitor</source>
         <translation>Monitor primario</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1147"/>
+        <location filename="../obconf.ui" line="1025"/>
         <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
-        <translation type="unfinished"></translation>
+        <translation>El muelle es un contenedor especial para &quot;dockapps&quot;, o aplicaciones anclables.  No se ve en la pantalla hasta que se ejecuta una &quot;dockapp&quot;.  Las &quot;dockapps&quot; se pueden usar para mostrar cosas como un reloj, o para proporcionarle una bandeja del sistema.</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1148"/>
+        <location filename="../obconf.ui" line="1041"/>
         <source>Position</source>
-        <translation type="unfinished"></translation>
+        <translation>Posición</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1149"/>
+        <location filename="../obconf.ui" line="1053"/>
         <source>&amp;Position:</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Posición:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1152"/>
+        <location filename="../obconf.ui" line="1067"/>
         <source>Top Left</source>
-        <translation type="unfinished"></translation>
+        <translation>Superior izquierda</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1153"/>
+        <location filename="../obconf.ui" line="1072"/>
         <source>Top</source>
-        <translation type="unfinished"></translation>
+        <translation>Arriba</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1154"/>
+        <location filename="../obconf.ui" line="1077"/>
         <source>Top Right</source>
-        <translation type="unfinished"></translation>
+        <translation>Superior derecha</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1155"/>
+        <location filename="../obconf.ui" line="1082"/>
         <source>Left</source>
-        <translation type="unfinished"></translation>
+        <translation>Izquierda</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1156"/>
+        <location filename="../obconf.ui" line="1087"/>
         <source>Right</source>
-        <translation type="unfinished"></translation>
+        <translation>Derecha</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1157"/>
+        <location filename="../obconf.ui" line="1092"/>
         <source>Bottom Left</source>
-        <translation type="unfinished"></translation>
+        <translation>Inferior izquierda</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1158"/>
+        <location filename="../obconf.ui" line="1097"/>
         <source>Bottom</source>
-        <translation type="unfinished"></translation>
+        <translation>Abajo</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1159"/>
+        <location filename="../obconf.ui" line="1102"/>
         <source>Bottom Right</source>
-        <translation type="unfinished"></translation>
+        <translation>Inferior derecha</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1160"/>
+        <location filename="../obconf.ui" line="1107"/>
         <source>Floating</source>
-        <translation type="unfinished"></translation>
+        <translation>Flotante</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1162"/>
+        <location filename="../obconf.ui" line="1121"/>
         <source>&amp;Floating position:</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Posición flotante:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1163"/>
+        <location filename="../obconf.ui" line="1146"/>
         <source>x</source>
-        <translation type="unfinished"></translation>
+        <translation>x</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1164"/>
+        <location filename="../obconf.ui" line="1162"/>
         <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
-        <translation type="unfinished"></translation>
+        <translation>Permitir que las ventanas sean colocadas en el área del muelle</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1165"/>
+        <location filename="../obconf.ui" line="1169"/>
         <source>&amp;Orientation: </source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Orientación: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1168"/>
+        <location filename="../obconf.ui" line="1183"/>
         <source>Vertical</source>
-        <translation type="unfinished"></translation>
+        <translation>Vertical</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1169"/>
+        <location filename="../obconf.ui" line="1188"/>
         <source>Horizontal</source>
-        <translation type="unfinished"></translation>
+        <translation>Horizontal</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1171"/>
+        <location filename="../obconf.ui" line="1199"/>
         <source>Stacking</source>
-        <translation type="unfinished"></translation>
+        <translation>Apilado</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1172"/>
+        <location filename="../obconf.ui" line="1205"/>
         <source>Keep dock &amp;above other windows</source>
-        <translation type="unfinished"></translation>
+        <translation>M&amp;antener el muelle sobre las demás ventanas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1173"/>
+        <location filename="../obconf.ui" line="1212"/>
         <source>A&amp;llow dock to be both above and below windows</source>
-        <translation type="unfinished"></translation>
+        <translation>Permitir que e&amp;l muelle esté tanto encima como debajo de las ventanas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1174"/>
+        <location filename="../obconf.ui" line="1219"/>
         <source>Keep dock &amp;below other windows</source>
-        <translation type="unfinished"></translation>
+        <translation>Mantener el muelle de&amp;bajo de otras ventanas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1175"/>
+        <location filename="../obconf.ui" line="1229"/>
         <source>Hiding</source>
-        <translation type="unfinished"></translation>
+        <translation>Ocultación</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1176"/>
+        <location filename="../obconf.ui" line="1235"/>
         <source>&amp;Delay before hiding:</source>
-        <translation type="unfinished"></translation>
+        <translation>Retraso antes &amp;de ocultar:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1177"/>
+        <location filename="../obconf.ui" line="1245"/>
         <source>Delay before &amp;showing:</source>
-        <translation type="unfinished"></translation>
+        <translation>Retraso antes de mo&amp;strar:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1178"/>
+        <location filename="../obconf.ui" line="1275"/>
         <source>&amp;Hide off screen</source>
-        <translation type="unfinished"></translation>
+        <translation>Ocultar fuera de la pantalla</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1179"/>
+        <location filename="../obconf.ui" line="1306"/>
         <source>About</source>
         <translation>Acerca de</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1036"/>
+        <location filename="../obconf.ui" line="96"/>
         <source>&amp;Install a new theme...</source>
         <translation>&amp;Instalar un tema nuevo…</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1037"/>
+        <location filename="../obconf.ui" line="103"/>
         <source>Create a theme &amp;archive (.obt)...</source>
-        <translation>Crear &amp;archivador de tema (.obt)…</translation>
+        <translation>Crea un &amp;archivo de tema (.obt)…</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1039"/>
+        <location filename="../obconf.ui" line="120"/>
         <source>&amp;Windows retain a border when undecorated</source>
         <translation>Las &amp;ventanas conservan un borde cuando no hay decoración</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1040"/>
+        <location filename="../obconf.ui" line="127"/>
         <source>A&amp;nimate iconify and restore</source>
         <translation>A&amp;nimación al minimizar y restaurar</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1056"/>
+        <location filename="../obconf.ui" line="231"/>
         <source>&amp;Active window title: </source>
         <translation>Título de ventana &amp;activa: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1057"/>
+        <location filename="../obconf.ui" line="241"/>
         <source>&amp;Inactive window title: </source>
         <translation>Título de ventana &amp;inactiva: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1058"/>
+        <location filename="../obconf.ui" line="251"/>
         <source>Menu &amp;header: </source>
         <translation>Encabe&amp;zamiento del menú: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1059"/>
+        <location filename="../obconf.ui" line="261"/>
         <source>&amp;Menu Item: </source>
         <translation>Elemento del &amp;menú: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1060"/>
+        <location filename="../obconf.ui" line="271"/>
         <source>Active &amp;On-screen display: </source>
         <translation>Visualización en &amp;pantalla activa: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1061"/>
+        <location filename="../obconf.ui" line="281"/>
         <source>Inactive O&amp;n-screen display: </source>
         <translation>Visualización en pa&amp;ntalla inactiva: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1062"/>
+        <location filename="../obconf.ui" line="295"/>
         <source>Focus &amp;new windows when they appear</source>
-        <translation>Enfocar las ventanas &amp;nuevas cuando aparecen</translation>
+        <translation>Activar las ventanas &amp;nuevas cuando aparecen</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1063"/>
+        <location filename="../obconf.ui" line="302"/>
         <source>&amp;Place new windows under the mouse pointer</source>
         <translation>&amp;Ubicar las ventanas nuevas bajo el puntero del ratón</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1064"/>
+        <location filename="../obconf.ui" line="309"/>
         <source>&amp;Center new windows when they are placed</source>
         <translation>&amp;Centrar las ventanas nuevas al ubicarlas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1065"/>
+        <location filename="../obconf.ui" line="318"/>
         <source>Prefer to place new windows &amp;on:</source>
         <translation>&amp;Ubicar las ventanas nuevas en:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1075"/>
+        <location filename="../obconf.ui" line="370"/>
         <source>Primary &amp;monitor:</source>
         <translation>&amp;Monitor primario:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1082"/>
+        <location filename="../obconf.ui" line="399"/>
         <source>&amp;Fixed monitor:</source>
         <translation>Monitor &amp;fijo:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1084"/>
+        <location filename="../obconf.ui" line="445"/>
         <source>Update the window contents while &amp;resizing</source>
         <translation>Actualizar contenido de la ventana al &amp;redimensionarla</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1085"/>
+        <location filename="../obconf.ui" line="452"/>
         <source>Drag &amp;threshold distance:</source>
-        <translation>&amp;Umbral de distancia del arrastre:</translation>
+        <translation>&amp;Umbral de distancia de arrastre:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1086"/>
+        <location filename="../obconf.ui" line="472"/>
         <source>Amount of resistance against other &amp;windows:</source>
         <translation>Cantidad de resistencia a otras &amp;ventanas:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1087"/>
+        <location filename="../obconf.ui" line="492"/>
         <source>Amount of resistance against screen &amp;edges:</source>
         <translation>Cantidad de resistencia a los bordes de la &amp;pantalla:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1088"/>
+        <location filename="../obconf.ui" line="512"/>
         <source>&amp;Amount of time to wait before switching:</source>
         <translation>&amp;Tiempo a esperar antes de cambiar:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1089"/>
+        <location filename="../obconf.ui" line="532"/>
         <source>&amp;Switch desktops when moving a window past the screen edge</source>
         <translation>Ca&amp;mbiar de escritorio al mover una ventana más allá del borde de la pantalla</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1097"/>
+        <location filename="../obconf.ui" line="567"/>
         <source>Fixed &amp;y position:</source>
         <translation>Posición &amp;Y fija:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1104"/>
+        <location filename="../obconf.ui" line="596"/>
         <source>Information dialog&apos;s &amp;position:</source>
         <translation>&amp;Posición del diálogo de información:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1105"/>
+        <location filename="../obconf.ui" line="606"/>
         <source>Fixed &amp;x position:</source>
         <translation>Posición &amp;X fija:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1106"/>
+        <location filename="../obconf.ui" line="616"/>
         <source>Show &amp;information dialog:</source>
         <translation>Mostrar diálogo de &amp;información:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1121"/>
+        <location filename="../obconf.ui" line="722"/>
         <source>&amp;Delay before focusing and raising windows:</source>
-        <translation>&amp;Retardo antes de enfocar y elevar ventanas:</translation>
+        <translation>&amp;Retardo antes de activar y elevar ventanas:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1122"/>
+        <location filename="../obconf.ui" line="742"/>
         <source>Move focus under the mouse when &amp;switching desktops</source>
         <translation>Mover el foco bajo el ratón al cam&amp;biar de escritorio</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1123"/>
+        <location filename="../obconf.ui" line="749"/>
         <source>Move focus &amp;under the mouse when the mouse is not moving</source>
         <translation>Mover el foco ba&amp;jo el ratón cuando éste no está en movimiento</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1124"/>
+        <location filename="../obconf.ui" line="756"/>
         <source>&amp;Raise windows when the mouse pointer moves over them</source>
         <translation>&amp;Elevar las ventanas cuando el puntero del ratón se mueve sobre ellas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1126"/>
+        <location filename="../obconf.ui" line="774"/>
         <source>Double click on the &amp;titlebar:</source>
         <translation>Pulsación doble en la barra de &amp;título:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1132"/>
+        <location filename="../obconf.ui" line="798"/>
         <source>Double click ti&amp;me:</source>
         <translation>Tie&amp;mpo de pulsación doble:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1133"/>
+        <location filename="../obconf.ui" line="838"/>
         <source>&amp;Show a notification when switching desktops</source>
         <translation>&amp;Mostrar notificación al cambiar de escritorio</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1134"/>
+        <location filename="../obconf.ui" line="845"/>
         <source>&amp;Amount of time to show the notification for:</source>
         <translation>Por &amp;cuánto tiempo mostrar la notificación:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1135"/>
+        <location filename="../obconf.ui" line="868"/>
         <source>&amp;Number of desktops: </source>
-        <translation>&amp;N.º de escritorios: </translation>
+        <translation>&amp;Número de escritorios: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1136"/>
+        <location filename="../obconf.ui" line="891"/>
         <source>&amp;Desktop names:</source>
         <translation>Nom&amp;bres de escritorios:</translation>
     </message>
@@ -616,31 +616,20 @@ The program is based on ObConf developed by the following developers.
 * Dana Jansens &lt;danakj@orodu.net&gt;
 * Tim Riley &lt;tr@slackzone.org&gt;
 * Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>A preferences manager for Openbox
+        <translation>Un gestor de preferencias para Openbox
 
-Copyright (c) 2003-2013
-
-Authors:
-* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
-* Dana Jansens &lt;danakj@orodu.net&gt;
-* Tim Riley &lt;tr@slackzone.org&gt;
-* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
-        <translation type="vanished">Un gestor de configuración para Openbox
-
-Copyright © 2003-2013
+Copyright (c) 2014-2015
 
 Autores:
 * Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
+
+El programa está basado en ObConf ObConf, desarrollado por los siguientes desarrolladores.
 * Dana Jansens &lt;danakj@orodu.net&gt;
 * Tim Riley &lt;tr@slackzone.org&gt;
 * Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
     </message>
     <message>
-        <location filename="../theme.cpp" line="150"/>
-        <location filename="../theme.cpp" line="160"/>
+        <location filename="../theme.cpp" line="149"/>
         <source>Choose an Openbox theme</source>
         <translation>Elija un tema de Openbox</translation>
     </message>
@@ -650,7 +639,7 @@ Autores:
     <message>
         <location filename="../archive.cpp" line="26"/>
         <source>&quot;%1&quot; was installed to %1</source>
-        <translation>Se instaló «%1» en %1</translation>
+        <translation>Se ha instalado «%1» en %1</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="53"/>
@@ -662,7 +651,7 @@ Autores:
         <source>Unable to create the theme archive &quot;%1&quot;.
 The following errors were reported:
 %2</source>
-        <translation>No se puede crear el archivador de tema «%1».
+        <translation>No se puede crear el archivo de tema «%1».
 Se produjeron los siguientes errores:
 %2</translation>
     </message>
@@ -694,7 +683,7 @@ Please ensure that &quot;%2&quot; is writable and that the file is a valid Openb
 The following errors were reported:
 %3</source>
         <translation>No se puede extraer el archivo «%1».
-Asegúrese de que «%2» es escribible y de que el archivo es un tema de Openbox válido.
+Asegúrese de que se puede escribir en «%2» y de que el archivo es un tema de Openbox válido.
 Se produjeron los siguientes errores:
 %3</translation>
     </message>
@@ -720,7 +709,7 @@ Opciones:
   --help                Mostrar esta ayuda y salir
   --version             Mostrar la versión y salir
   --install ARCHIVADOR.obt Instalar el tema dado y seleccionarlo
-  --archive TEMA        Crear un archivador a partir de la carpeta dada
+  --archive TEMA        Crear un archivo a partir de la carpeta dada
   --config-file ARCHIVO Especificar ruta al archivo de conf. a usar
 </translation>
     </message>
@@ -746,18 +735,18 @@ Opciones:
 </translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="221"/>
-        <location filename="../obconf-qt.cpp" line="237"/>
+        <location filename="../obconf-qt.cpp" line="223"/>
+        <location filename="../obconf-qt.cpp" line="238"/>
         <source>Error</source>
         <translation>Error</translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="222"/>
+        <location filename="../obconf-qt.cpp" line="224"/>
         <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
         <translation>Falló la carga de un rc.xml. Puede que la instalación de Openbox sea incorrecta.</translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="235"/>
+        <location filename="../obconf-qt.cpp" line="236"/>
         <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.
 
 Message: %1</source>
