@@ -17,237 +17,237 @@
 <context>
     <name>MainDialog</name>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1027"/>
+        <location filename="../obconf.ui" line="63"/>
         <source>Mouse</source>
         <translation>Rato</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1012"/>
+        <location filename="../obconf.ui" line="14"/>
         <source>Window Manager Preferences</source>
-        <translation>Preferências de gestor de janelas</translation>
+        <translation>Preferências do gestor de janelas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1017"/>
+        <location filename="../obconf.ui" line="38"/>
         <source>Theme</source>
         <translation>Tema</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1019"/>
+        <location filename="../obconf.ui" line="43"/>
         <source>Appearance</source>
         <translation>Aparência</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1021"/>
+        <location filename="../obconf.ui" line="48"/>
         <source>Font</source>
         <translation>Tipo de letra</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1023"/>
-        <location filename="../../build/src/ui_obconf.h" line="1038"/>
+        <location filename="../obconf.ui" line="53"/>
+        <location filename="../obconf.ui" line="114"/>
         <source>Windows</source>
         <translation>Janelas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1025"/>
+        <location filename="../obconf.ui" line="58"/>
         <source>Move &amp; Resize</source>
         <translation>Mover e redimensionar</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1029"/>
+        <location filename="../obconf.ui" line="68"/>
         <source>Desktops</source>
         <translation>Áreas de trabalho</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1031"/>
+        <location filename="../obconf.ui" line="73"/>
         <source>Margins</source>
         <translation>Margens</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1033"/>
+        <location filename="../obconf.ui" line="78"/>
         <source>Dock</source>
         <translation>Doca</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1041"/>
+        <location filename="../obconf.ui" line="137"/>
         <source>Window Titles</source>
         <translation>Título das janelas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1042"/>
+        <location filename="../obconf.ui" line="143"/>
         <source>Button order:</source>
         <translation>Ordem dos botões:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1083"/>
+        <location filename="../obconf.ui" line="439"/>
         <source>Moving and Resizing Windows</source>
-        <translation>Movimentação e redimensionamento de janelas</translation>
+        <translation>Mover e dimensionar janelas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1090"/>
+        <location filename="../obconf.ui" line="542"/>
         <source>Information Dialog</source>
         <translation>Diálogos</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1119"/>
+        <location filename="../obconf.ui" line="701"/>
         <source>Focusing Windows</source>
         <translation>Foco de janelas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1120"/>
+        <location filename="../obconf.ui" line="710"/>
         <source>Focus windows when the mouse pointer moves over them</source>
         <translation>Focar janelas ao passar com o ponteiro do rato</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1125"/>
+        <location filename="../obconf.ui" line="768"/>
         <source>Titlebar</source>
         <translation>Barra de título</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1137"/>
+        <location filename="../obconf.ui" line="905"/>
         <source>Desktop Margins</source>
         <translation>Margens da área de trabalho</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1138"/>
+        <location filename="../obconf.ui" line="911"/>
         <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
         <translation>As margens da área de trabalho são as áreas reservadas nos limites do ecrã. As janelas não serão colocadas nas margens e as janelas maximizadas também não as cobrirão.</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1139"/>
+        <location filename="../obconf.ui" line="921"/>
         <source>Left:</source>
         <translation>Esquerda:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1140"/>
-        <location filename="../../build/src/ui_obconf.h" line="1142"/>
-        <location filename="../../build/src/ui_obconf.h" line="1144"/>
-        <location filename="../../build/src/ui_obconf.h" line="1146"/>
+        <location filename="../obconf.ui" line="935"/>
+        <location filename="../obconf.ui" line="956"/>
+        <location filename="../obconf.ui" line="977"/>
+        <location filename="../obconf.ui" line="998"/>
         <source>px</source>
         <translation>px</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1141"/>
+        <location filename="../obconf.ui" line="942"/>
         <source>Top:</source>
         <translation>Superior:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1143"/>
+        <location filename="../obconf.ui" line="963"/>
         <source>Right:</source>
         <translation>Direita:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1145"/>
+        <location filename="../obconf.ui" line="984"/>
         <source>Bottom:</source>
         <translation>Inferior:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1068"/>
+        <location filename="../obconf.ui" line="329"/>
         <source>All monitors</source>
         <translation>Todos os monitores</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1069"/>
+        <location filename="../obconf.ui" line="334"/>
         <source>The active monitor</source>
         <translation>Monitor ativo</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1070"/>
+        <location filename="../obconf.ui" line="339"/>
         <source>The monitor with the mouse</source>
         <translation>Monitor com o ponteiro do rato</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1073"/>
+        <location filename="../obconf.ui" line="354"/>
         <source>Primary Monitor</source>
         <translation>Monitor principal</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1074"/>
+        <location filename="../obconf.ui" line="360"/>
         <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
-        <translation>O monitor principal é aquele em que o Openbox apresenta os diálogos, tais como o diálogo para percorrer janelas.</translation>
+        <translation>O monitor principal é aquele em que o Openbox mostra os diálogos, tais como o diálogo para percorrer janelas.</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1078"/>
+        <location filename="../obconf.ui" line="381"/>
         <source>Fixed Monitor</source>
         <translation>Monitor fixo</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1079"/>
+        <location filename="../obconf.ui" line="386"/>
         <source>Active Monitor</source>
         <translation>Monitor ativo</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1080"/>
+        <location filename="../obconf.ui" line="391"/>
         <source>Monitor With Mouse Pointer</source>
         <translation>Monitor com o ponteiro do rato</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1093"/>
-        <location filename="../../build/src/ui_obconf.h" line="1100"/>
+        <location filename="../obconf.ui" line="549"/>
+        <location filename="../obconf.ui" line="578"/>
         <source>Centered</source>
         <translation>Centro</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1094"/>
+        <location filename="../obconf.ui" line="554"/>
         <source>From left edge</source>
         <translation>Da margem esquerda</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1095"/>
+        <location filename="../obconf.ui" line="559"/>
         <source>From right edge</source>
         <translation>Da margem direita</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1101"/>
+        <location filename="../obconf.ui" line="583"/>
         <source>From top edge</source>
         <translation>Da margem superior</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1102"/>
+        <location filename="../obconf.ui" line="588"/>
         <source>From bottom edge</source>
         <translation>Da margem inferior</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1109"/>
+        <location filename="../obconf.ui" line="641"/>
         <source>When resizing terminal windows</source>
         <translation>Ao redimensionar as janelas de terminal</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1110"/>
+        <location filename="../obconf.ui" line="646"/>
         <source>Always</source>
         <translation>Sempre</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1111"/>
+        <location filename="../obconf.ui" line="651"/>
         <source>Never</source>
         <translation>Nunca</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1115"/>
+        <location filename="../obconf.ui" line="660"/>
         <source>Centered on the window</source>
         <translation>Centrar na janela</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1116"/>
+        <location filename="../obconf.ui" line="665"/>
         <source>Above the window</source>
         <translation>Por cima da janela</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1117"/>
+        <location filename="../obconf.ui" line="670"/>
         <source>Fixed position on screen</source>
         <translation>Posição fixa no ecrã</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1129"/>
+        <location filename="../obconf.ui" line="785"/>
         <source>Maximizes the window</source>
         <translation>Maximiza a janela</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1130"/>
+        <location filename="../obconf.ui" line="790"/>
         <source>Shades the window</source>
         <translation>Enrola a janela</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1043"/>
+        <location filename="../obconf.ui" line="153"/>
         <source>N: Window icon
 L: Window label (Title)
 I: Iconify (Minimize)
@@ -255,7 +255,7 @@ M: Maximize
 C: Close
 S: Shade (Roll up)
 D: Omnipresent (On all desktops)</source>
-        <translation>N: Window icon
+        <translation>N: Ícone da janela
 L: Título da janela
 I: Minimizar
 M: Maximizar
@@ -264,322 +264,322 @@ S: Enrolar
 D: Omnipresente (todas as áreas de trabalho)</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1071"/>
+        <location filename="../obconf.ui" line="344"/>
         <source>Primary monitor</source>
         <translation>Monitor principal</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1147"/>
+        <location filename="../obconf.ui" line="1025"/>
         <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
-        <translation type="unfinished"></translation>
+        <translation>A doca é uma área em que se colocam os ícones das aplicações ou &quot;dockapps&quot;. Esta área apenas está visível de estiver a executar uma &quot;dockapp&quot;. Com as &quot;dockapps&quot; pode  mostrar um relógio e mostrar a bandeja do sistema.</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1148"/>
+        <location filename="../obconf.ui" line="1041"/>
         <source>Position</source>
-        <translation type="unfinished"></translation>
+        <translation>Posição</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1149"/>
+        <location filename="../obconf.ui" line="1053"/>
         <source>&amp;Position:</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Posição:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1152"/>
+        <location filename="../obconf.ui" line="1067"/>
         <source>Top Left</source>
-        <translation type="unfinished"></translation>
+        <translation>Cima/esquerda</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1153"/>
+        <location filename="../obconf.ui" line="1072"/>
         <source>Top</source>
-        <translation type="unfinished"></translation>
+        <translation>Cima</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1154"/>
+        <location filename="../obconf.ui" line="1077"/>
         <source>Top Right</source>
-        <translation type="unfinished"></translation>
+        <translation>Cima/direita</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1155"/>
+        <location filename="../obconf.ui" line="1082"/>
         <source>Left</source>
-        <translation type="unfinished"></translation>
+        <translation>Esquerda</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1156"/>
+        <location filename="../obconf.ui" line="1087"/>
         <source>Right</source>
-        <translation type="unfinished"></translation>
+        <translation>Direita</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1157"/>
+        <location filename="../obconf.ui" line="1092"/>
         <source>Bottom Left</source>
-        <translation type="unfinished"></translation>
+        <translation>Baixo/esquerda</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1158"/>
+        <location filename="../obconf.ui" line="1097"/>
         <source>Bottom</source>
-        <translation type="unfinished"></translation>
+        <translation>Baixo</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1159"/>
+        <location filename="../obconf.ui" line="1102"/>
         <source>Bottom Right</source>
-        <translation type="unfinished"></translation>
+        <translation>Baixo/esquerda</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1160"/>
+        <location filename="../obconf.ui" line="1107"/>
         <source>Floating</source>
-        <translation type="unfinished"></translation>
+        <translation>Flutuante</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1162"/>
+        <location filename="../obconf.ui" line="1121"/>
         <source>&amp;Floating position:</source>
-        <translation type="unfinished"></translation>
+        <translation>Posição &amp;flutuante:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1163"/>
+        <location filename="../obconf.ui" line="1146"/>
         <source>x</source>
-        <translation type="unfinished"></translation>
+        <translation>x</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1164"/>
+        <location filename="../obconf.ui" line="1162"/>
         <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
-        <translation type="unfinished"></translation>
+        <translation>Permitir &amp;colocação de janelas na área da doca</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1165"/>
+        <location filename="../obconf.ui" line="1169"/>
         <source>&amp;Orientation: </source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Orientação: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1168"/>
+        <location filename="../obconf.ui" line="1183"/>
         <source>Vertical</source>
-        <translation type="unfinished"></translation>
+        <translation>Vertical</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1169"/>
+        <location filename="../obconf.ui" line="1188"/>
         <source>Horizontal</source>
-        <translation type="unfinished"></translation>
+        <translation>Horizontal</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1171"/>
+        <location filename="../obconf.ui" line="1199"/>
         <source>Stacking</source>
-        <translation type="unfinished"></translation>
+        <translation>Empilhamento</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1172"/>
+        <location filename="../obconf.ui" line="1205"/>
         <source>Keep dock &amp;above other windows</source>
-        <translation type="unfinished"></translation>
+        <translation>Manter doc&amp;a à frente das janelas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1173"/>
+        <location filename="../obconf.ui" line="1212"/>
         <source>A&amp;llow dock to be both above and below windows</source>
-        <translation type="unfinished"></translation>
+        <translation>Permitir doca à frente e por trás das jane&amp;las</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1174"/>
+        <location filename="../obconf.ui" line="1219"/>
         <source>Keep dock &amp;below other windows</source>
-        <translation type="unfinished"></translation>
+        <translation>Manter do&amp;ca atrás das janelas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1175"/>
+        <location filename="../obconf.ui" line="1229"/>
         <source>Hiding</source>
-        <translation type="unfinished"></translation>
+        <translation>Ocultar</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1176"/>
+        <location filename="../obconf.ui" line="1235"/>
         <source>&amp;Delay before hiding:</source>
-        <translation type="unfinished"></translation>
+        <translation>Atrso antes &amp;de ocultar:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1177"/>
+        <location filename="../obconf.ui" line="1245"/>
         <source>Delay before &amp;showing:</source>
-        <translation type="unfinished"></translation>
+        <translation>Atra&amp;so antes de mostrar:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1178"/>
+        <location filename="../obconf.ui" line="1275"/>
         <source>&amp;Hide off screen</source>
-        <translation type="unfinished"></translation>
+        <translation>Ocultar fora do &amp;ecrã</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1179"/>
+        <location filename="../obconf.ui" line="1306"/>
         <source>About</source>
-        <translation>Sobre</translation>
+        <translation>Acerca</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1036"/>
+        <location filename="../obconf.ui" line="96"/>
         <source>&amp;Install a new theme...</source>
         <translation>&amp;Instalar um tema...</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1037"/>
+        <location filename="../obconf.ui" line="103"/>
         <source>Create a theme &amp;archive (.obt)...</source>
-        <translation> Criar um &amp;arquivo de tema (.obt)...</translation>
+        <translation>Criar um &amp;arquivo de tema (.obt)...</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1039"/>
+        <location filename="../obconf.ui" line="120"/>
         <source>&amp;Windows retain a border when undecorated</source>
         <translation>As &amp;janelas possuem contorno mesmo que não decoradas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1040"/>
+        <location filename="../obconf.ui" line="127"/>
         <source>A&amp;nimate iconify and restore</source>
         <translation>A&amp;nimar minimização e restauro</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1056"/>
+        <location filename="../obconf.ui" line="231"/>
         <source>&amp;Active window title: </source>
         <translation>Título da janela &amp;ativa: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1057"/>
+        <location filename="../obconf.ui" line="241"/>
         <source>&amp;Inactive window title: </source>
         <translation>Título da janela &amp;inativa: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1058"/>
+        <location filename="../obconf.ui" line="251"/>
         <source>Menu &amp;header: </source>
         <translation>Cabeçal&amp;lho de menu: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1059"/>
+        <location filename="../obconf.ui" line="261"/>
         <source>&amp;Menu Item: </source>
         <translation>Item de &amp;menu: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1060"/>
+        <location filename="../obconf.ui" line="271"/>
         <source>Active &amp;On-screen display: </source>
         <translation>Visualização no ecrã (&amp;OSD) ativo: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1061"/>
+        <location filename="../obconf.ui" line="281"/>
         <source>Inactive O&amp;n-screen display: </source>
         <translation>Visualização no ecrã (O&amp;SD) inativo: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1062"/>
+        <location filename="../obconf.ui" line="295"/>
         <source>Focus &amp;new windows when they appear</source>
         <translation>Focar &amp;novas janelas assim que aparecerem</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1063"/>
+        <location filename="../obconf.ui" line="302"/>
         <source>&amp;Place new windows under the mouse pointer</source>
         <translation>&amp;Posicionar novas janelas por baixo do ponteiro do rato</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1064"/>
+        <location filename="../obconf.ui" line="309"/>
         <source>&amp;Center new windows when they are placed</source>
         <translation>&amp;Centrar novas janelas assim que forem posicionadas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1065"/>
+        <location filename="../obconf.ui" line="318"/>
         <source>Prefer to place new windows &amp;on:</source>
         <translation>C&amp;olocar novas janelas em:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1075"/>
+        <location filename="../obconf.ui" line="370"/>
         <source>Primary &amp;monitor:</source>
         <translation>&amp;Monitor principal:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1082"/>
+        <location filename="../obconf.ui" line="399"/>
         <source>&amp;Fixed monitor:</source>
         <translation>Monitor &amp;fixo:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1084"/>
+        <location filename="../obconf.ui" line="445"/>
         <source>Update the window contents while &amp;resizing</source>
         <translation>Atualizar conteúdo da janela ao &amp;redimensionar</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1085"/>
+        <location filename="../obconf.ui" line="452"/>
         <source>Drag &amp;threshold distance:</source>
         <translation>Dis&amp;tância de arrasto:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1086"/>
+        <location filename="../obconf.ui" line="472"/>
         <source>Amount of resistance against other &amp;windows:</source>
         <translation>Resistência em relação às outras &amp;janelas:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1087"/>
+        <location filename="../obconf.ui" line="492"/>
         <source>Amount of resistance against screen &amp;edges:</source>
         <translation>Resistência em relação aos limit&amp;es do ecrã:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1088"/>
+        <location filename="../obconf.ui" line="512"/>
         <source>&amp;Amount of time to wait before switching:</source>
         <translation>Tempo de esper&amp;a antes de trocar:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1089"/>
+        <location filename="../obconf.ui" line="532"/>
         <source>&amp;Switch desktops when moving a window past the screen edge</source>
         <translation>Trocar de área de trabalho ao mover a janela para além do&amp;s limites do ecrã</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1097"/>
+        <location filename="../obconf.ui" line="567"/>
         <source>Fixed &amp;y position:</source>
         <translation>Posição &amp;Y:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1104"/>
+        <location filename="../obconf.ui" line="596"/>
         <source>Information dialog&apos;s &amp;position:</source>
         <translation>&amp;Posição do diálogo:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1105"/>
+        <location filename="../obconf.ui" line="606"/>
         <source>Fixed &amp;x position:</source>
         <translation>Posição &amp;X:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1106"/>
+        <location filename="../obconf.ui" line="616"/>
         <source>Show &amp;information dialog:</source>
         <translation>Mostrar d&amp;iálogo de informações:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1121"/>
+        <location filename="../obconf.ui" line="722"/>
         <source>&amp;Delay before focusing and raising windows:</source>
         <translation>Atraso antes &amp;de focar e mostrar janelas:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1122"/>
+        <location filename="../obconf.ui" line="742"/>
         <source>Move focus under the mouse when &amp;switching desktops</source>
         <translation>Mover foco para bai&amp;xo do rato ao trocar de área de trabalho</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1123"/>
+        <location filename="../obconf.ui" line="749"/>
         <source>Move focus &amp;under the mouse when the mouse is not moving</source>
         <translation>Mover foco para baixo do rato se este não esti&amp;ver em movimento</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1124"/>
+        <location filename="../obconf.ui" line="756"/>
         <source>&amp;Raise windows when the mouse pointer moves over them</source>
         <translation>Most&amp;rar janelas ao passar o rato sobre as mesmas</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1126"/>
+        <location filename="../obconf.ui" line="774"/>
         <source>Double click on the &amp;titlebar:</source>
         <translation>Duplo clique na barra de &amp;título:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1132"/>
+        <location filename="../obconf.ui" line="798"/>
         <source>Double click ti&amp;me:</source>
         <translation>Te&amp;mpo do duplo clique:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1133"/>
+        <location filename="../obconf.ui" line="838"/>
         <source>&amp;Show a notification when switching desktops</source>
         <translation>Mo&amp;strar notificação ao trocar a área de trabalho</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1134"/>
+        <location filename="../obconf.ui" line="845"/>
         <source>&amp;Amount of time to show the notification for:</source>
         <translation>Mostr&amp;ar notificação durante:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1135"/>
+        <location filename="../obconf.ui" line="868"/>
         <source>&amp;Number of desktops: </source>
         <translation>&amp;Número de áreas de trabalho: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1136"/>
+        <location filename="../obconf.ui" line="891"/>
         <source>&amp;Desktop names:</source>
         <translation>Nome das áreas &amp;de trabalho:</translation>
     </message>
@@ -601,7 +601,7 @@ D: Omnipresente (todas as áreas de trabalho)</translation>
     <message>
         <location filename="../maindialog.cpp" line="76"/>
         <source>About ObConf-Qt</source>
-        <translation>Sobre o ObConf-Qt</translation>
+        <translation>Acerca de ObConf-Qt</translation>
     </message>
     <message>
         <location filename="../maindialog.cpp" line="77"/>
@@ -616,31 +616,20 @@ The program is based on ObConf developed by the following developers.
 * Dana Jansens &lt;danakj@orodu.net&gt;
 * Tim Riley &lt;tr@slackzone.org&gt;
 * Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>A preferences manager for Openbox
+        <translation>Um gestor para as preferências Openbox
 
-Copyright (c) 2003-2013
-
-Authors:
-* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
-* Dana Jansens &lt;danakj@orodu.net&gt;
-* Tim Riley &lt;tr@slackzone.org&gt;
-* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
-        <translation type="vanished">O gestor de definições do Openbox
-
-Copyright (c) 2003-2013
+Copyright (c) 2014-2019
 
 Autores:
 * Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
+
+Este programa foi baseado em ObConf, desenvolvido pelas pessoas abaixo indicadas.
 * Dana Jansens &lt;danakj@orodu.net&gt;
 * Tim Riley &lt;tr@slackzone.org&gt;
 * Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
     </message>
     <message>
-        <location filename="../theme.cpp" line="150"/>
-        <location filename="../theme.cpp" line="160"/>
+        <location filename="../theme.cpp" line="149"/>
         <source>Choose an Openbox theme</source>
         <translation>Escolha o tema Openbox</translation>
     </message>
@@ -680,7 +669,7 @@ Foram reportados os seguintes erros:
     <message>
         <location filename="../archive.cpp" line="138"/>
         <source>&quot;%1&quot; does not appear to be a valid Openbox theme directory</source>
-        <translation>&quot;%1&quot; não parece ser um diretório válido para temas Openbox</translation>
+        <translation>Parece que &quot;%1&quot; não é um diretório válido para temas Openbox</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="148"/>
@@ -694,7 +683,7 @@ Please ensure that &quot;%2&quot; is writable and that the file is a valid Openb
 The following errors were reported:
 %3</source>
         <translation>Não foi possível extrair o ficheiro &quot;%1!
-Certifique-se que tem permissões de escrita em &quot;%2&quot; e que o ficheiro é um arquivo de tema Openbox.
+verifique se tem permissões de escrita em &quot;%2&quot; e que o ficheiro é um arquivo de tema Openbox.
 Foram reportados os seguintes erros:
 %3</translation>
     </message>
@@ -746,18 +735,18 @@ Opções:
 </translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="221"/>
-        <location filename="../obconf-qt.cpp" line="237"/>
+        <location filename="../obconf-qt.cpp" line="223"/>
+        <location filename="../obconf-qt.cpp" line="238"/>
         <source>Error</source>
         <translation>Erro</translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="222"/>
+        <location filename="../obconf-qt.cpp" line="224"/>
         <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
         <translation>Erro ao carregar rc.xml. É possível que o Openbox não esteja bem instalado.</translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="235"/>
+        <location filename="../obconf-qt.cpp" line="236"/>
         <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.
 
 Message: %1</source>
@@ -780,11 +769,11 @@ under certain conditions. See the file COPYING for details.
         <translation>Copyright (c) 2003-2008   Dana Jansens
 Copyright (c) 2003            Tim Riley
 Copyright (c) 2007            Javeed Shaikh
-Copyright (c) 2013            Hong Jen Yee (PCMan)
+Copyright (c) 2013-2019            Hong Jen Yee (PCMan)
 
 Este programa NÃO POSSUI QUALQUER GARANTIA.
-É um programa livre e é permitida a sua redistribuição
-mediante alguma condições. Consulte o ficheiro COPYING para mais informações.
+É um programa livre e a sua redistribuição é permitida mediante
+alguma condições. Consulte o ficheiro COPYING para mais informações.
 
 </translation>
     </message>
