@@ -17,88 +17,88 @@
 <context>
     <name>MainDialog</name>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1012"/>
+        <location filename="../obconf.ui" line="14"/>
         <source>Window Manager Preferences</source>
         <translation>Настройки менеджера окон</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1017"/>
+        <location filename="../obconf.ui" line="38"/>
         <source>Theme</source>
         <translation>Тема</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1019"/>
+        <location filename="../obconf.ui" line="43"/>
         <source>Appearance</source>
         <translation>Внешний вид</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1021"/>
+        <location filename="../obconf.ui" line="48"/>
         <source>Font</source>
         <translation>Шрифт</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1023"/>
-        <location filename="../../build/src/ui_obconf.h" line="1038"/>
+        <location filename="../obconf.ui" line="53"/>
+        <location filename="../obconf.ui" line="114"/>
         <source>Windows</source>
         <translation>Окна</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1025"/>
+        <location filename="../obconf.ui" line="58"/>
         <source>Move &amp; Resize</source>
         <translation>Перемещение и изменение размера</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1027"/>
+        <location filename="../obconf.ui" line="63"/>
         <source>Mouse</source>
         <translation>Мышь</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1029"/>
+        <location filename="../obconf.ui" line="68"/>
         <source>Desktops</source>
         <translation>Рабочие столы</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1031"/>
+        <location filename="../obconf.ui" line="73"/>
         <source>Margins</source>
         <translation>Границы</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1033"/>
+        <location filename="../obconf.ui" line="78"/>
         <source>Dock</source>
         <translation>Док</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1036"/>
+        <location filename="../obconf.ui" line="96"/>
         <source>&amp;Install a new theme...</source>
         <translation>&amp;Установить новую тему...</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1037"/>
+        <location filename="../obconf.ui" line="103"/>
         <source>Create a theme &amp;archive (.obt)...</source>
         <translation>Создать &amp;архив с темой (.obt)...</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1039"/>
+        <location filename="../obconf.ui" line="120"/>
         <source>&amp;Windows retain a border when undecorated</source>
         <translation>&amp;Окна без декораций сохраняют края</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1040"/>
+        <location filename="../obconf.ui" line="127"/>
         <source>A&amp;nimate iconify and restore</source>
         <translation>А&amp;нимировать сворачивание и восстановление окна</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1041"/>
+        <location filename="../obconf.ui" line="137"/>
         <source>Window Titles</source>
         <translation>Заголовки окна</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1042"/>
+        <location filename="../obconf.ui" line="143"/>
         <source>Button order:</source>
         <translation>Порядок кнопок:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1043"/>
+        <location filename="../obconf.ui" line="153"/>
         <source>N: Window icon
 L: Window label (Title)
 I: Iconify (Minimize)
@@ -115,471 +115,471 @@ S: Свернуть в заголовок окна
 D: На все рабочие столы</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1056"/>
+        <location filename="../obconf.ui" line="231"/>
         <source>&amp;Active window title: </source>
         <translation>Название &amp;активного окна: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1057"/>
+        <location filename="../obconf.ui" line="241"/>
         <source>&amp;Inactive window title: </source>
         <translation>Название &amp;неактивного окна: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1058"/>
+        <location filename="../obconf.ui" line="251"/>
         <source>Menu &amp;header: </source>
         <translation>&amp;Заголовок меню: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1059"/>
+        <location filename="../obconf.ui" line="261"/>
         <source>&amp;Menu Item: </source>
         <translation>Пункт &amp;меню: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1060"/>
+        <location filename="../obconf.ui" line="271"/>
         <source>Active &amp;On-screen display: </source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Активная надпись на экране: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1061"/>
+        <location filename="../obconf.ui" line="281"/>
         <source>Inactive O&amp;n-screen display: </source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Неактивная надпись на экране: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1062"/>
+        <location filename="../obconf.ui" line="295"/>
         <source>Focus &amp;new windows when they appear</source>
         <translation>Передавать фокус &amp;новым окнам при их возникновении</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1063"/>
+        <location filename="../obconf.ui" line="302"/>
         <source>&amp;Place new windows under the mouse pointer</source>
         <translation>&amp;Помещать новые окна под курсором мыши</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1064"/>
+        <location filename="../obconf.ui" line="309"/>
         <source>&amp;Center new windows when they are placed</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Выравнивать новые окна по центру</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1065"/>
+        <location filename="../obconf.ui" line="318"/>
         <source>Prefer to place new windows &amp;on:</source>
         <translation>Предпочитать размещать новое окно &amp;на:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1068"/>
+        <location filename="../obconf.ui" line="329"/>
         <source>All monitors</source>
         <translation>Всех мониторах</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1069"/>
+        <location filename="../obconf.ui" line="334"/>
         <source>The active monitor</source>
         <translation>Активном мониторе</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1070"/>
+        <location filename="../obconf.ui" line="339"/>
         <source>The monitor with the mouse</source>
         <translation>Мониторе с мышью</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1071"/>
+        <location filename="../obconf.ui" line="344"/>
         <source>Primary monitor</source>
         <translation>Основном мониторе</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1073"/>
+        <location filename="../obconf.ui" line="354"/>
         <source>Primary Monitor</source>
         <translation>Основной монитор</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1074"/>
+        <location filename="../obconf.ui" line="360"/>
         <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
         <translation>Основной монитор - это область, где Openbox будет размещать диалоги, такие как переключение окон.</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1075"/>
+        <location filename="../obconf.ui" line="370"/>
         <source>Primary &amp;monitor:</source>
         <translation>Основной &amp;монитор:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1078"/>
+        <location filename="../obconf.ui" line="381"/>
         <source>Fixed Monitor</source>
         <translation>Фиксированный монитор</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1079"/>
+        <location filename="../obconf.ui" line="386"/>
         <source>Active Monitor</source>
         <translation>Активный монитор</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1080"/>
+        <location filename="../obconf.ui" line="391"/>
         <source>Monitor With Mouse Pointer</source>
         <translation>Монитор с курсором мыши</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1082"/>
+        <location filename="../obconf.ui" line="399"/>
         <source>&amp;Fixed monitor:</source>
         <translation>&amp;Фиксированный монитор:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1083"/>
+        <location filename="../obconf.ui" line="439"/>
         <source>Moving and Resizing Windows</source>
         <translation>Перемещение и изменение размеров окон</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1084"/>
+        <location filename="../obconf.ui" line="445"/>
         <source>Update the window contents while &amp;resizing</source>
         <translation>Обновлять содержимое окна во &amp;время изменения размера</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1085"/>
+        <location filename="../obconf.ui" line="452"/>
         <source>Drag &amp;threshold distance:</source>
         <translation>&amp;Порог расстояния перетаскивания:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1086"/>
+        <location filename="../obconf.ui" line="472"/>
         <source>Amount of resistance against other &amp;windows:</source>
         <translation>Количество сопротивления к другим &amp;окнам:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1087"/>
+        <location filename="../obconf.ui" line="492"/>
         <source>Amount of resistance against screen &amp;edges:</source>
         <translation>Количество сопротивления к &amp;краям экрана:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1088"/>
+        <location filename="../obconf.ui" line="512"/>
         <source>&amp;Amount of time to wait before switching:</source>
         <translation>&amp;Время ожидания перед переключением:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1089"/>
+        <location filename="../obconf.ui" line="532"/>
         <source>&amp;Switch desktops when moving a window past the screen edge</source>
         <translation>&amp;Переключать рабочие столы при перемещенииокна за границы экрана</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1090"/>
+        <location filename="../obconf.ui" line="542"/>
         <source>Information Dialog</source>
         <translation>Информагионный диалог</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1093"/>
-        <location filename="../../build/src/ui_obconf.h" line="1100"/>
+        <location filename="../obconf.ui" line="549"/>
+        <location filename="../obconf.ui" line="578"/>
         <source>Centered</source>
         <translation>По центру</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1094"/>
+        <location filename="../obconf.ui" line="554"/>
         <source>From left edge</source>
         <translation>От левого края</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1095"/>
+        <location filename="../obconf.ui" line="559"/>
         <source>From right edge</source>
         <translation>От правого края</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1097"/>
+        <location filename="../obconf.ui" line="567"/>
         <source>Fixed &amp;y position:</source>
         <translation>Фиксированное по &amp;y:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1101"/>
+        <location filename="../obconf.ui" line="583"/>
         <source>From top edge</source>
         <translation>Отверхеней границы</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1102"/>
+        <location filename="../obconf.ui" line="588"/>
         <source>From bottom edge</source>
         <translation>От нижней границы</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1104"/>
+        <location filename="../obconf.ui" line="596"/>
         <source>Information dialog&apos;s &amp;position:</source>
         <translation>&amp;Расположение информационного диалога:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1105"/>
+        <location filename="../obconf.ui" line="606"/>
         <source>Fixed &amp;x position:</source>
         <translation>Фиксированное по &amp;x:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1106"/>
+        <location filename="../obconf.ui" line="616"/>
         <source>Show &amp;information dialog:</source>
         <translation>Показывать &amp;информационный диалог:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1109"/>
+        <location filename="../obconf.ui" line="641"/>
         <source>When resizing terminal windows</source>
-        <translation type="unfinished"></translation>
+        <translation>При изменении размеров окон терминалов</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1110"/>
+        <location filename="../obconf.ui" line="646"/>
         <source>Always</source>
         <translation>Всегда</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1111"/>
+        <location filename="../obconf.ui" line="651"/>
         <source>Never</source>
         <translation>Никогда</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1115"/>
+        <location filename="../obconf.ui" line="660"/>
         <source>Centered on the window</source>
         <translation>По центру окна</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1116"/>
+        <location filename="../obconf.ui" line="665"/>
         <source>Above the window</source>
         <translation>Сверху окна</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1117"/>
+        <location filename="../obconf.ui" line="670"/>
         <source>Fixed position on screen</source>
         <translation>Фиксированное место на экране</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1119"/>
+        <location filename="../obconf.ui" line="701"/>
         <source>Focusing Windows</source>
         <translation>Передача фокуса окнам</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1120"/>
+        <location filename="../obconf.ui" line="710"/>
         <source>Focus windows when the mouse pointer moves over them</source>
         <translation>Передавать фокус окнам, когда курсор перемещается над ними</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1121"/>
+        <location filename="../obconf.ui" line="722"/>
         <source>&amp;Delay before focusing and raising windows:</source>
         <translation>&amp;Задержка перед передачей курсора и поднятием окна:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1122"/>
+        <location filename="../obconf.ui" line="742"/>
         <source>Move focus under the mouse when &amp;switching desktops</source>
         <translation>Передавать фокус под курсор при &amp;переключении рабочих столов</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1123"/>
+        <location filename="../obconf.ui" line="749"/>
         <source>Move focus &amp;under the mouse when the mouse is not moving</source>
         <translation>Передавать фокус  &amp;под курсор, когда мышь не двигается</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1124"/>
+        <location filename="../obconf.ui" line="756"/>
         <source>&amp;Raise windows when the mouse pointer moves over them</source>
         <translation>&amp;Поднимать окна, когда курсор двигается по ним</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1125"/>
+        <location filename="../obconf.ui" line="768"/>
         <source>Titlebar</source>
         <translation>Заголовок окна</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1126"/>
+        <location filename="../obconf.ui" line="774"/>
         <source>Double click on the &amp;titlebar:</source>
         <translation>Двойной клик на &amp;заголовке окна:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1129"/>
+        <location filename="../obconf.ui" line="785"/>
         <source>Maximizes the window</source>
         <translation>Разворачивает окно</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1130"/>
+        <location filename="../obconf.ui" line="790"/>
         <source>Shades the window</source>
         <translation>Сворачивает окно в заголовок</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1132"/>
+        <location filename="../obconf.ui" line="798"/>
         <source>Double click ti&amp;me:</source>
         <translation>&amp;Время двойного клика:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1133"/>
+        <location filename="../obconf.ui" line="838"/>
         <source>&amp;Show a notification when switching desktops</source>
         <translation>&amp;Показывать уведомление при переключении рабочих столов</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1134"/>
+        <location filename="../obconf.ui" line="845"/>
         <source>&amp;Amount of time to show the notification for:</source>
         <translation>&amp;Время, на протяжении которого показывается уведомление:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1135"/>
+        <location filename="../obconf.ui" line="868"/>
         <source>&amp;Number of desktops: </source>
         <translation>&amp;Количество рабочих столов: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1136"/>
+        <location filename="../obconf.ui" line="891"/>
         <source>&amp;Desktop names:</source>
         <translation>Названия &amp;рабочих столов:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1137"/>
+        <location filename="../obconf.ui" line="905"/>
         <source>Desktop Margins</source>
         <translation>Границы рабочего стола</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1138"/>
+        <location filename="../obconf.ui" line="911"/>
         <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
         <translation>Границы рабочего стола - это зарезервированные зоны по вашего экрана. Новые окна не будут помещены в рамках границ, и развёрнутые окна не перекроют их.</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1139"/>
+        <location filename="../obconf.ui" line="921"/>
         <source>Left:</source>
         <translation>Слева:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1140"/>
-        <location filename="../../build/src/ui_obconf.h" line="1142"/>
-        <location filename="../../build/src/ui_obconf.h" line="1144"/>
-        <location filename="../../build/src/ui_obconf.h" line="1146"/>
+        <location filename="../obconf.ui" line="935"/>
+        <location filename="../obconf.ui" line="956"/>
+        <location filename="../obconf.ui" line="977"/>
+        <location filename="../obconf.ui" line="998"/>
         <source>px</source>
         <translation>пикс</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1141"/>
+        <location filename="../obconf.ui" line="942"/>
         <source>Top:</source>
         <translation>Сверху:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1143"/>
+        <location filename="../obconf.ui" line="963"/>
         <source>Right:</source>
         <translation>Справа:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1145"/>
+        <location filename="../obconf.ui" line="984"/>
         <source>Bottom:</source>
         <translation>Снизу:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1147"/>
+        <location filename="../obconf.ui" line="1025"/>
         <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
-        <translation type="unfinished"></translation>
+        <translation>Док - это специальный контейнер для &quot;dockapps&quot;, или приложений дока. Он не отображается на экране, пока не запущены эти приложения. Приложения дока могут быть использованы для показа таких вещей, как часы, или отображения системного лотка.</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1148"/>
+        <location filename="../obconf.ui" line="1041"/>
         <source>Position</source>
-        <translation type="unfinished"></translation>
+        <translation>Расположение</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1149"/>
+        <location filename="../obconf.ui" line="1053"/>
         <source>&amp;Position:</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Расположение:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1152"/>
+        <location filename="../obconf.ui" line="1067"/>
         <source>Top Left</source>
-        <translation type="unfinished"></translation>
+        <translation>Вверху слева</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1153"/>
+        <location filename="../obconf.ui" line="1072"/>
         <source>Top</source>
-        <translation type="unfinished"></translation>
+        <translation>Вверху</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1154"/>
+        <location filename="../obconf.ui" line="1077"/>
         <source>Top Right</source>
-        <translation type="unfinished"></translation>
+        <translation>Вверху справа</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1155"/>
+        <location filename="../obconf.ui" line="1082"/>
         <source>Left</source>
-        <translation type="unfinished"></translation>
+        <translation>Слева</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1156"/>
+        <location filename="../obconf.ui" line="1087"/>
         <source>Right</source>
-        <translation type="unfinished"></translation>
+        <translation>Справа</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1157"/>
+        <location filename="../obconf.ui" line="1092"/>
         <source>Bottom Left</source>
-        <translation type="unfinished"></translation>
+        <translation>Снизу слева</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1158"/>
+        <location filename="../obconf.ui" line="1097"/>
         <source>Bottom</source>
-        <translation type="unfinished"></translation>
+        <translation>Снизу</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1159"/>
+        <location filename="../obconf.ui" line="1102"/>
         <source>Bottom Right</source>
-        <translation type="unfinished"></translation>
+        <translation>Снизу справа</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1160"/>
+        <location filename="../obconf.ui" line="1107"/>
         <source>Floating</source>
-        <translation type="unfinished"></translation>
+        <translation>Плавающее</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1162"/>
+        <location filename="../obconf.ui" line="1121"/>
         <source>&amp;Floating position:</source>
-        <translation type="unfinished"></translation>
+        <translation>П&amp;лавающее расположение:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1163"/>
+        <location filename="../obconf.ui" line="1146"/>
         <source>x</source>
-        <translation type="unfinished"></translation>
+        <translation>x</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1164"/>
+        <location filename="../obconf.ui" line="1162"/>
         <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
-        <translation type="unfinished"></translation>
+        <translation>Разрешить &amp;размещать окна внутри области дока</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1165"/>
+        <location filename="../obconf.ui" line="1169"/>
         <source>&amp;Orientation: </source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Ориентация: </translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1168"/>
+        <location filename="../obconf.ui" line="1183"/>
         <source>Vertical</source>
-        <translation type="unfinished"></translation>
+        <translation>Вертикально</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1169"/>
+        <location filename="../obconf.ui" line="1188"/>
         <source>Horizontal</source>
-        <translation type="unfinished"></translation>
+        <translation>Горизонтально</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1171"/>
+        <location filename="../obconf.ui" line="1199"/>
         <source>Stacking</source>
-        <translation type="unfinished"></translation>
+        <translation>Стопкой</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1172"/>
+        <location filename="../obconf.ui" line="1205"/>
         <source>Keep dock &amp;above other windows</source>
-        <translation type="unfinished"></translation>
+        <translation>Отображать док &amp;поверх других окон</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1173"/>
+        <location filename="../obconf.ui" line="1212"/>
         <source>A&amp;llow dock to be both above and below windows</source>
-        <translation type="unfinished"></translation>
+        <translation>Разрешить размещать док &amp;как поверх, так и позади окон</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1174"/>
+        <location filename="../obconf.ui" line="1219"/>
         <source>Keep dock &amp;below other windows</source>
-        <translation type="unfinished"></translation>
+        <translation>Отображать док по&amp;зади других окон</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1175"/>
+        <location filename="../obconf.ui" line="1229"/>
         <source>Hiding</source>
-        <translation type="unfinished"></translation>
+        <translation>Скрывать док</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1176"/>
+        <location filename="../obconf.ui" line="1235"/>
         <source>&amp;Delay before hiding:</source>
-        <translation type="unfinished"></translation>
+        <translation>Задержка перед &amp;скрытием:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1177"/>
+        <location filename="../obconf.ui" line="1245"/>
         <source>Delay before &amp;showing:</source>
-        <translation type="unfinished"></translation>
+        <translation>Задержка перед &amp;показом:</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1178"/>
+        <location filename="../obconf.ui" line="1275"/>
         <source>&amp;Hide off screen</source>
-        <translation type="unfinished"></translation>
+        <translation>С&amp;крывать с экрана</translation>
     </message>
     <message>
-        <location filename="../../build/src/ui_obconf.h" line="1179"/>
+        <location filename="../obconf.ui" line="1306"/>
         <source>About</source>
         <translation>О программе</translation>
     </message>
@@ -611,24 +611,14 @@ The program is based on ObConf developed by the following developers.
 * Dana Jansens &lt;danakj@orodu.net&gt;
 * Tim Riley &lt;tr@slackzone.org&gt;
 * Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>A preferences manager for Openbox
+        <translation>Менеджер настроек Openbox
 
-Copyright (c) 2003-2013
-
-Authors:
-* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
-* Dana Jansens &lt;danakj@orodu.net&gt;
-* Tim Riley &lt;tr@slackzone.org&gt;
-* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
-        <translation type="vanished">Диспетчер настроек для Openbox
-
-Copyright (c) 2003-2013
+Copyright (c) 2014-2015
 
 Авторы:
 * Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
+
+Эта программа основана на ObConf, созданной следующими разработчиками:
 * Dana Jansens &lt;danakj@orodu.net&gt;
 * Tim Riley &lt;tr@slackzone.org&gt;
 * Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
@@ -639,8 +629,7 @@ Copyright (c) 2003-2013
         <translation>Индивидуальные действия</translation>
     </message>
     <message>
-        <location filename="../theme.cpp" line="150"/>
-        <location filename="../theme.cpp" line="160"/>
+        <location filename="../theme.cpp" line="149"/>
         <source>Choose an Openbox theme</source>
         <translation>Выбрать тему для Openbox</translation>
     </message>
@@ -675,17 +664,17 @@ The following errors were reported:
     <message>
         <location filename="../archive.cpp" line="115"/>
         <source>Unable to create directory &quot;%1&quot;: %2</source>
-        <translation>Не удалось создать папку &quot;%1&quot;: %2</translation>
+        <translation>Не удалось создать каталог &quot;%1&quot;: %2</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="138"/>
         <source>&quot;%1&quot; does not appear to be a valid Openbox theme directory</source>
-        <translation>&quot;%1&quot; не является правильной папкой тем Openbox</translation>
+        <translation>&quot;%1&quot; не является корректным каталогом тем Openbox</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="148"/>
         <source>Unable to move to directory &quot;%1&quot;: %2</source>
-        <translation>Невозможно переместить в папку &quot;%1&quot;: %2</translation>
+        <translation>Невозможно переместить в каталог &quot;%1&quot;: %2</translation>
     </message>
     <message>
         <location filename="../archive.cpp" line="185"/>
@@ -736,14 +725,15 @@ Options:
   --archive THEME       Create a theme archive from the given theme directory
   --config-file FILE    Specify the path to the config file to use
 </source>
-        <translation>Синтаксис: obconf [опции] [ARCHIVE.obt]
+        <translation>Синтаксис: obconf [опции] [АРХИВ.obt]
 
 Опции:
-  --help                оказать эту справку и выйти
+  --help                Показать эту справку и выйти
   --version             Показать версию и выйти
-  --install ARCHIVE.obt Установить тему из указанного архива и выбрать её
-  --archive THEME       Создать архив с темой из указаннойпапки с темой
-  --config-file FILE    Выбрать путь к используемому файлу настроек</translation>
+  --install АРХИВ.obt   Установить тему из указанного архива и выбрать её
+  --archive ТЕМА        Создать архива темы из указанного каталога темы
+  --config-file ФАЙЛ    Выбрать путь к используемому файлу настроек
+</translation>
     </message>
     <message>
         <location filename="../obconf-qt.cpp" line="97"/>
@@ -767,22 +757,22 @@ Options:
 </translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="221"/>
-        <location filename="../obconf-qt.cpp" line="237"/>
+        <location filename="../obconf-qt.cpp" line="223"/>
+        <location filename="../obconf-qt.cpp" line="238"/>
         <source>Error</source>
         <translation>Ошибка</translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="222"/>
+        <location filename="../obconf-qt.cpp" line="224"/>
         <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
         <translation>Не удалось загрузить rc.xml. Openbox, наверное, не установлен правильно.</translation>
     </message>
     <message>
-        <location filename="../obconf-qt.cpp" line="235"/>
+        <location filename="../obconf-qt.cpp" line="236"/>
         <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.
 
 Message: %1</source>
-        <translation>Ошибка при разборе файла конфигурации Openbox. Ваш конфигурационный файл неправильный XML.
+        <translation>Ошибка при разборе файла настроек Openbox. Данный файл настроек не является корректным XML-документом.
 
 Сообщение: %1</translation>
     </message>
